<?php
/**
 * Allows reading RSS feeds
 *
 * Reads data from an RSS feed using SimpleXML.
 * This is a PHP5-only class!
 *
 * $Id: tgcRSS.php,v 1.1 2004/09/24 01:25:49 luckec Exp $
 *
 * @package     tgcRSS
 * @author      Carsten Lucke <luckec@tool-garage.de>
 * @copyright   Carsten Lucke <luckec@tool-garage.de>
 */

/**
 * Manage include-path
 */  
if(! defined('TGCRSS_INCLUDE_PATH')) {
    define('TGCRSS_INCLUDE_PATH', dirname( __FILE__ ));
}

/**
 * include informationbase-class
 */
require_once TGCRSS_INCLUDE_PATH . '/tgcRSS/Information.php';

/**
 * include reader baseclass
 */ 
require_once TGCRSS_INCLUDE_PATH . '/tgcRSS/Reader.php';

/**
 * tgcRSSException - always thrown on failure
 *
 * @package     tgcRSS
 * @subpackage  tgcRSSException
 * @access      public
 * @version     1.0.0
 * @author      Carsten Lucke <luckec@tool-garage.de>
 */
class tgcRSSException extends Exception {};
 
/**
 * Allows reading RSS feeds
 *
 * Reads data from an RSS feed using SimpleXML.
 * This is a PHP5-only class!
 *
 * $Id: tgcRSS.php,v 1.1 2004/09/24 01:25:49 luckec Exp $
 *
 * @package     tgcRSS
 * @access      public
 * @version     0.1.0
 * @author      Carsten Lucke <luckec@tool-garage.de>
 */
class tgcRSS
{
   /**
    * SimpleXML Object that allows reading the feed-data
    * 
    * @var  object
    */
    private $_reader;
    
   /**
    * Channel-object
    * 
    * @var  object tgcRSS_Channel
    */
    private $_channel = null;
    
   /**
    * items-object array
    * 
    * @var  array
    */
    private $_items = null;
    
   /**
    * Constructor
    * 
    * @param    string  $feedURI    RSS-feed uri
    * @param    string  $backend    used backend to process the feed's contents (Expat|Dom)
    * @throws   tgcRSSException     throws if the RSS-feed could not be loaded
    */
    public function __construct($feedURI, $backend = 'Expat')
    {
        $data = file_get_contents($feedURI);
        
        if (! $data) {
            throw new tgcRSSException('Unable to retrieve the RSS-feed\'s contents');
        }
        
        // instantiate reader
        $readerClass = 'tgcRSS_Reader_' . $backend;
        
        @include_once TGCRSS_INCLUDE_PATH . '/' . str_replace('_', '/', $readerClass) . '.php';
        if (! class_exists($readerClass)) {
            throw new tgcRSSException('Unable to load backend: ' . $backend);
        }
        
        $this->_reader = new $readerClass($data);
    }
    
   /**
    * Returns the RSS-feed's raw data
    * 
    * @return   string
    */
    public function getXML()
    {
        return $this->_reader->getXML();
    }
    
   /**
    * Returns the items of the RSS-feed.
    * 
    * @return   array   Array containing tgcRSS_Item objects
    * @throws   tgcRSSException
    */
    public function getItems()
    {
        return $this->_reader->getItems();
    }
    
   /**
    * Returns the channel information of the RSS-feed.
    * 
    * @return   tgcRSSChannel   channel-object
    * @throws   tgcRSSException thrown if no channel-node is found
    */
    public function getChannelInfo()
    {
        return $this->_reader->getChannelInfo();
    }
    
   /**
    * Returns the image-information of the RSS-feed.
    * 
    * @return   tgcRSSImageInfo channel-object
    * @throws   tgcRSSException
    */
    public function getImageInfo()
    {
        return $this->_reader->getImageInfo();
    }
    
   /**
    * Returns the textinput-information of the RSS-feed.
    * 
    * @return   tgcRSSTextinput textinput-object
    * @throws   tgcRSSException
    */
    public function getTextinput()
    {
        return $this->_reader->getTextinput();
    }
}
?>
