<?php
/**
 * Class that implements some interfaces to ease access on information 
 * about items, channel, etc.
 * 
 * $Id: Information.php,v 1.1 2004/09/24 01:25:49 luckec Exp $
 *
 * @package     tgcRSS
 * @author      Carsten Lucke <luckec@tool-garage.de>
 * @copyright
 */
 
/**
 * Required Iterator
 */
require_once 'tgc/tgcSPL/RecursiveArrayIterator.php';
 
/**
 * Class that implements some interfaces to ease access on information 
 * about items, channel, etc.
 * 
 * $Id: Information.php,v 1.1 2004/09/24 01:25:49 luckec Exp $
 *
 * @package     tgcRSS
 * @access      public
 * @version     0.1
 * @author      Carsten Lucke <luckec@tool-garage.de>
 */
class tgcRSS_Information implements ArrayAccess
{
   /**
    * Informational-data stack
    * 
    * @var  array
    */
    protected $data;
    
   /**
    * Constructor
    */
    public function __construct($data = array())
    {
        $this->data = $data;
    }
    
   /**
    * Hooks in when printing the object
    * 
    * @acess    public
    */
    public function __toString()
    {
        $out = get_class($this) . "::__toString():\n";
        $rit = new RecursiveIteratorIterator(new tgcSPL_RecursiveArrayIterator($this->data), RIT_SELF_FIRST);
        foreach ($rit as $key => $value) {
            $out .= str_repeat('   ', $rit->getDepth());
            $out .= '[' . $key . '] => ' . $value . "\n";
        }
        return $out;
    }
    
   /**
    * Needed to implement ArrayAccess
    * 
    * @param    string  $offset offset
    */
    public function offsetExists($offset)
    {
        return isset($this->data[$offset]);
    }
    
   /**
    * Needed to implement ArrayAccess
    * 
    * @param    string  $offset offset
    * @return   mixed   value
    */
    public function offsetGet($offset)
    {
        return $this->data[$offset];
    }
    
   /**
    * Needed to implement ArrayAccess
    * 
    * @param    string  $offset offset
    * @param    mixed   $value  value
    */
    public function offsetSet($offset, $value)
    {
        $this->data[$offset] = $value;
    }
    
   /**
    * Needed to implement ArrayAccess
    * 
    * @param    string  $offset offset
    */
    public function offsetUnset($offset)
    {
        unset($this->data[$offset]);
    }
}


/**
 * Item of the RSS-feed
 * 
 * $Id: Information.php,v 1.1 2004/09/24 01:25:49 luckec Exp $
 *
 * @package     tgcRSS
 * @access      public
 * @version     0.1.0
 * @author      Carsten Lucke <luckec@tool-garage.de>
 * @todo        implement interface ArrayAccess
 */
class tgcRSS_Item extends tgcRSS_Information 
{
}

 
/**
 * Class representing the RSS-feed channel information
 * 
 * $Id: Information.php,v 1.1 2004/09/24 01:25:49 luckec Exp $
 *
 * @package     tgcRSS
 * @access      public
 * @version     0.1
 * @author      Carsten Lucke <luckec@tool-garage.de>
 */
class tgcRSS_Channel extends tgcRSS_Information 
{
}
 

/**
 * Class representing the RSS-feed image-information
 * 
 * $Id: Information.php,v 1.1 2004/09/24 01:25:49 luckec Exp $
 *
 * @package     tgcRSS
 * @access      public
 * @version     0.1
 * @author      Carsten Lucke <luckec@tool-garage.de>
 */
class tgcRSS_Image extends tgcRSS_Information 
{
}
 

/**
 * Class representing the RSS-feed textinput-information
 * 
 * $Id: Information.php,v 1.1 2004/09/24 01:25:49 luckec Exp $
 *
 * @package     tgcRSS
 * @access      public
 * @version     0.1
 * @author      Carsten Lucke <luckec@tool-garage.de>
 */
class tgcRSS_Textinput extends tgcRSS_Information 
{
}
?>
