<?php
/**
 * Abstract reader class
 *
 * @package     tgcRSS
 * @subpackage  Reader
 * @author      Carsten Lucke <luckec@tool-garage.de>
 * @copyright   Carsten Lucke <luckec@tool-garage.de>
 */
 
 
/**
 * Abstract reader class
 *
 * @package     tgcRSS
 * @subpackage  Reader
 * @access      public
 * @version     0.1.0
 * @author      Carsten Lucke <luckec@tool-garage.de>
 */
abstract class tgcRSS_Reader implements tgcRSS_Interface_Reader  
{
   /**
    * The RSS-feed's XML
    * 
    * @var  string
    */
    protected $xml;
    
   /**
    * RSS feed's default namespace-uri
    * 
    * @var  string
    */
    protected $defaultNSUri = '';
    
   /**
    * Reader-driver
    * 
    * @var  object
    */
    protected $driver;
    
   /**
    * Channel-information 
    * 
    * @var  array
    */
    protected $channel = array();
    
   /**
    * Image-information 
    * 
    * @var  array
    */
    protected $image = array();
    
   /**
    * Items
    * 
    * @var  array
    */
    protected $items = array();
    
   /**
    * Textinput information
    * 
    * @var  array
    */
    protected $textinput = array();
    
   /**
    * Constructor
    * 
    * @param    string  $xml    xml
    * @throws   tgcRSSException
    */
    public function __construct($xml)
    {
        $this->xml = $xml;
        
        // catch the default namespace-uri, if available
        if (preg_match('[^:]xmlns="([^"]+)"', $this->xml, $matches = array())) {
            $this->defaultNSUri = $matches[1];
        }
    }
    
   /**
    * Returns the RSS-feed's raw XML
    * 
    * @return   string  RSS-feed XML
    */
    public function getXML()
    {
        return $this->xml;
    }
}

/**
 * RSS-feed reader interface
 */
interface tgcRSS_Interface_Reader {
   /**
    * Constructor
    * 
    * @param    string  $xml    xml
    */
    public function __construct($xml);
    
   /**
    * Returns the RSS-feed's raw XML
    * 
    * @return   string  RSS-feed XML
    */
    public function getXML();
    
   /**
    * Returns the information about the RSS-feed's channel
    * 
    * @return   tgcRSS_Channel  channel-object
    * @throws   tgcRSSException
    */
    public function getChannelInfo();
    
   /**
    * Returns the information of the RSS-feed's image-tag
    * 
    * @return   tgcRSS_Image    image-object
    * @throws   tgcRSSException
    */
    public function getImageInfo();
    
   /**
    * Returns the information about the RSS-feed's item(s)
    * 
    * @return   array   array containing tgcRSS_Item objects
    * @throws   tgcRSSException
    */
    public function getItems();
    
   /**
    * Returns the information of the RSS-feed's textinput-tag
    * 
    * @return   tgcRSS_Textinput    image-object
    * @throws   tgcRSSException
    */
    public function getTextinput();
};
?>
